/* 
 * File:   spi.h
 * Author: sprut
 *
 * Created on 4. Mrz 2020, 21:16
 */

#ifndef SPI_H
#define	SPI_H


//******************************************************************************************************
// definitions for SPI
//******************************************************************************************************
/* SSPSTAT REGISTER */

// Master SPI mode only

#define   SMPEND        0b10000000           // Input data sample at end of data out             
#define   SMPMID        0b00000000           // Input data sample at middle of data out

#define   SPI_MODE_00       0b00000000              // Setting for SPI bus Mode 0,0
//CKE           0x40                   // SSPSTAT register 
//CKP           0x00                   // SSPCON1 register 

#define   SPI_MODE_01       0b00000001              // Setting for SPI bus Mode 0,1
//CKE           0x00                   // SSPSTAT register 
//CKP           0x00                   // SSPCON1 register

#define   SPI_MODE_10       0b00000010              // Setting for SPI bus Mode 1,0
//CKE           0x40                   // SSPSTAT register
//CKP           0x10                   // SSPCON1 register

#define   SPI_MODE_11       0b00000011              // Setting for SPI bus Mode 1,1
//CKE           0x00                   // SSPSTAT register
//CKP           0x10                   // SSPCON1 register

/* SSPCON1 REGISTER */
#define   SPI_SSPENB        0b00100000           // Enable serial port and configures SCK, SDO, SDI

#define   SPI_FOSC_4    0b00000000              // SPI Master mode, clock = Fosc/4
#define   SPI_FOSC_16   0b00000001              // SPI Master mode, clock = Fosc/16
#define   SPI_FOSC_64   0b00000010              // SPI Master mode, clock = Fosc/64
#define   SPI_FOSC_TMR2 0b00000011              // SPI Master mode, clock = TMR2 output/2
#define   SLV_SSON      0b00000100              // SPI Slave mode, /SS pin control enabled
#define   SLV_SSOFF     0b00000101              // SPI Slave mode, /SS pin control disabled



//******************************************************************************************************
// definitions for RS232
//******************************************************************************************************
#define RsTx        LATCbits.LATC6
#define Rs_Delay    104                        // 104us/bit = 9600 baud

//****************************************************************************************************************
// vorabdeklarationen
//****************************************************************************************************************

char SPI32Tx(unsigned long int data);
char SPI8Tx(unsigned char data);
void OpenSPI( unsigned char sync_mode, unsigned char bus_mode, unsigned char smp_phase);

void OpenMyRs232(void);
void TxCharMyRs232(char value);
void TxDWordMyRs232(unsigned long int data);


//*****************************************************************************************************************

#endif	/* SPI_H */

